pyLBM.boundary.Boundary_method
==============================

.. currentmodule:: pyLBM.boundary

.. autoclass:: Boundary_method

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Boundary_method.prepare_rhs



   

